@@ -3,9 +3,11 @@
 import vtk
 import pathlib
 from typing import Tuple
-from .actor import Actor
 from .camera import Camera
 from .types import ImageTypes
+from .actor import Actor
+
+from typing import List
 
 
 class Assistant:
@@ -18,20 +20,22 @@ class Assistant:
     Args:
         background_color: A tuple of three integers that represent RGB values of the
             color that you'd like to set as the background color.
-        actors: A dictionary of actors from a Scene object
+        actors: A list of actors.
         camera: A Camera object.
         legend_parameters: A list of legend parameter objects to be added to the scene
+
     """
 
     def __init__(self, background_color: Tuple[int, int, int], camera: Camera,
-                 actors: dict, legend_parameters: list) -> None:
+                 actors: List[Actor], legend_parameters: list) -> None:
 
         self._background_color = background_color
         self._actors = actors
         self._camera = camera
         self._legend_params = legend_parameters
 
-    def _create_window(self) -> None:
+    def _create_window(self) -> \
+            Tuple[vtk.vtkRenderWindowInteractor, vtk.vtkRenderWindow, vtk.vtkRenderer]:
         """Create a rendering window with a single renderer and an interactor.
 
         The objects are embedded inside each other. interactor is the outmost layer.
@@ -58,7 +62,7 @@ class Assistant:
         renderer = vtk.vtkRenderer()
 
         # Add actors to the window
-        for actor in self._actors.values():
+        for actor in self._actors:
             renderer.AddActor(actor.to_vtk())
 
         # Add legends to the window
@@ -81,7 +85,9 @@ class Assistant:
         renderer.TwoSidedLightingOn()
 
         renderer.SetActiveCamera(self._camera.to_vtk())
-        renderer.ResetCamera()
+
+        if self._camera.reset_camera:
+            renderer.ResetCamera()
 
         # the order is from outside to inside
         return interactor, window, renderer
