@@ -3,9 +3,12 @@
 import click
 from .translate import translate
 from .export import export
+from .config import config
 from honeybee.cli import main
 
 # command group for all radiance extension commands.
+
+
 @click.group(help='honeybee-vtk commands.')
 @click.version_option()
 def vtk():
@@ -15,5 +18,6 @@ def vtk():
 # add sub-commands to vtk
 vtk.add_command(translate)
 vtk.add_command(export)
+vtk.add_command(config)
 
-main.add_command(vtk)
\ No newline at end of file
+main.add_command(vtk)
