@@ -56,7 +56,8 @@ def export():
     '--grid-display-mode', '-gdm',
     type=click.Choice(['shaded', 'surface', 'surfacewithedges',
                        'wireframe', 'points'], case_sensitive=False),
-    default='shaded', help='Set display mode for the Sensorgrids.', show_default=True
+    default='surfacewithedges', help='Set display mode for the Sensorgrids.',
+    show_default=True
 )
 @click.option(
     '--view', '-vf', help='File Path to the Radiance view file. Multiple view files are'
@@ -73,10 +74,20 @@ def export():
     help='Validate simulation data before loading on the model. This is recommended'
     ' when using this command locally.', show_default=True
 )
+@click.option(
+    '--grid/--model', is_flag=True, default=False, help='Boolean to decide whether to export'
+    ' the images of a whole model or only the grids. Set it to True to export the grids.',
+    show_default=True
+)
+@click.option(
+    '--grid-filter', '-gf', type=str, default=[], show_default=True, multiple=True,
+    help='Filter sensor grids by name. Use this option multiple times to use multiple'
+    ' grid identifiers as filters.'
+)
 def export(
         hbjson_file, folder, image_type, image_width, image_height,
         background_color, model_display_mode, grid_options, grid_display_mode, view,
-        config, validate_data):
+        config, validate_data, grid, grid_filter):
     """Export images from radiance views in a HBJSON file.
 
     \b
@@ -124,23 +135,35 @@ def export(
     # Set model's grid's display mode
     if grid_display_mode == 'shaded':
         grid_display_mode = DisplayMode.Shaded
-    elif model_display_mode == 'surface':
+    elif grid_display_mode == 'surface':
         grid_display_mode = DisplayMode.Surface
-    elif model_display_mode == 'surfacewithedges':
+    elif grid_display_mode == 'surfacewithedges':
         grid_display_mode = DisplayMode.SurfaceWithEdges
-    elif model_display_mode == 'wireframe':
+    elif grid_display_mode == 'wireframe':
         grid_display_mode = DisplayMode.Wireframe
-    elif model_display_mode == 'points':
+    elif grid_display_mode == 'points':
         grid_display_mode = DisplayMode.Points
 
+
     try:
         model = Model.from_hbjson(hbjson=hbjson_file, load_grids=grid_options)
-        output = model.to_images(folder=folder, config=config, validation=validate_data,
-                                 model_display_mode=model_display_mode,
-                                 grid_display_mode=grid_display_mode,
-                                 background_color=background_color, view=view,
-                                 image_type=image_type, image_width=image_width,
-                                 image_height=image_height,)
+
+        if not grid:
+            output = model.to_images(folder=folder, config=config,
+                                     validation=validate_data,
+                                     model_display_mode=model_display_mode,
+                                     grid_display_mode=grid_display_mode,
+                                     background_color=background_color, view=view,
+                                     image_type=image_type, image_width=image_width,
+                                     image_height=image_height,)
+        else:
+            output = model.to_grid_images(config=config, folder=folder,
+                                          grid_filter=grid_filter,
+                                          grid_display_mode=grid_display_mode,
+                                          background_color=background_color,
+                                          image_type=image_type,
+                                          image_width=image_width,
+                                          image_height=image_height)
 
     except Exception:
         traceback.print_exc()
