@@ -1,7 +1,7 @@
 """Vtk legend parameters."""
 
 import vtk
-from ladybug.color import Colorset, Color
+from ladybug.color import Colorset
 from enum import Enum, auto
 from typing import Tuple, Union
 from ._helper import _validate_input
@@ -91,37 +91,6 @@ color_set = {
 }
 
 
-color_set = {
-    'annual_comfort': Colorset.annual_comfort(),
-    'benefit': Colorset.benefit(),
-    'benefit_harm': Colorset.benefit_harm(),
-    'black_to_white': Colorset.black_to_white(),
-    'blue_green_red': Colorset.blue_green_red(),
-    'cloud_cover': Colorset.cloud_cover(),
-    'cold_sensation': Colorset.cold_sensation(),
-    'ecotect': Colorset.ecotect(),
-    'energy_balance': Colorset.energy_balance(),
-    'energy_balance_storage': Colorset.energy_balance_storage(),
-    'glare_study': Colorset.glare_study(),
-    'harm': Colorset.harm(),
-    'heat_sensation': Colorset.heat_sensation(),
-    'multi_colored': Colorset.multi_colored(),
-    'multicolored_2': Colorset.multicolored_2(),
-    'multicolored_3': Colorset.multicolored_3(),
-    'nuanced': Colorset.nuanced(),
-    'openstudio_palette': Colorset.openstudio_palette(),
-    'original': Colorset.original(),
-    'peak_load_balance': Colorset.peak_load_balance(),
-    'shade_benefit': Colorset.shade_benefit(),
-    'shade_benefit_harm': Colorset.shade_benefit_harm(),
-    'shade_harm': Colorset.shade_harm(),
-    'shadow_study': Colorset.shadow_study(),
-    'therm': Colorset.therm(),
-    'thermal_comfort': Colorset.thermal_comfort(),
-    'view_study': Colorset.view_study()
-}
-
-
 class Text:
     """Text parameters for the legend.
 
@@ -295,7 +264,6 @@ class LegendParameter:
         self.min = min
         self.max = max
         self.auto_range = auto_range
-        self._range = None
 
     @property
     def name(self) -> str:
@@ -566,48 +534,30 @@ class LegendParameter:
                 f'Max must be a number. Instead got {val}.'
             )
 
-    @property
-    def auto_range(self) -> Tuple[float, float]:
-        """A tuple with min and max values in the legend."""
-        return self._auto_range
-
-    @auto_range.setter
-    def auto_range(self, val) -> None:
-        if not val:
-            self._auto_range = None
-        elif isinstance(val, (tuple, list)) and _validate_input(
-                val, [float, int], num_val=2):
-            self._auto_range = val
-        else:
-            raise ValueError(
-                'Range takes a tuple or a list of integers.'
-                f' Instead got {val}.'
-            )
-
     @property
     def range(self) -> Tuple[float, float]:
         if self._min == None and self._max == None:
-            return self._auto_range
+            return self.auto_range
 
         elif self._min and self._max == None:
-            if self._min < self._auto_range[1]:
-                return (self._min, self._auto_range[1])
+            if self._min < self.auto_range[1]:
+                return (self._min, self.auto_range[1])
             else:
                 raise ValueError(
                     f'In {self._name},'
                     f' min value {self._min} must be less than auto-calculated'
-                    f' max value {self._auto_range[1]}. Either update min value or'
+                    f' max value {self.auto_range[1]}. Either update min value or'
                     ' provide a max value.'
                 )
 
         elif self._min == None and self._max:
-            if self._max > self._auto_range[0]:
-                return (self._auto_range[0], self._max)
+            if self._max > self.auto_range[0]:
+                return (self.auto_range[0], self._max)
             else:
                 raise ValueError(
                     f'In {self._name},'
                     f' max value {self._max} must be greater than auto-calculated'
-                    f' max value {self._auto_range[1]}. Either update max value or'
+                    f' max value {self.auto_range[1]}. Either update max value or'
                     ' provide a min value.'
                 )
 
@@ -621,6 +571,23 @@ class LegendParameter:
                     f' value {self._min}.'
                 )
 
+    def _to_dict(self) -> dict:
+        """Get the legend parameters as a dictionary object.
+
+        This method is only used in the 'translate' command.
+        """
+        return {
+            'name': self.name,
+            'unit': self.unit,
+            'colors': self.colors.value,
+            'hide_legend': self.hide_legend,
+            'color_count': self.color_count,
+            'label_count': self.label_count,
+            'min': self.min,
+            'max': self.max,
+            'range': self.range
+        }
+
     def get_lookuptable(self) -> vtk.vtkLookupTable:
         """Get a vtk lookuptable."""
         minimum, maximum = self.range
@@ -696,7 +663,6 @@ class LegendParameter:
             f' Position of label: {self._preceding_labels} |'
             f' Font of label: {self._label_parameters} |'
             f' Font of title: {self._title_parameters} |'
-            f' Legend auto-range: {self._auto_range} |'
             f' Legend min: {self._min} |'
             f' Legend max: {self._max} |'
             f' Legend range: {self.range} |'
