@@ -13,10 +13,13 @@ import warnings
 
 from collections import defaultdict
 from typing import Dict, List, Union, Tuple
+
 from honeybee.facetype import face_types
 from honeybee.model import Model as HBModel
 from honeybee_radiance.sensorgrid import SensorGrid
+from honeybee_radiance.sensor import Sensor
 from ladybug.color import Color
+from ladybug_geometry.geometry3d.pointvector import Point3D
 
 from .actor import Actor
 from .scene import Scene
@@ -27,7 +30,7 @@ from .to_vtk import convert_aperture, convert_face, convert_room, convert_shade,
 from .vtkjs.schema import IndexJSON, DisplayMode, SensorGridOptions
 from .vtkjs.helper import convert_directory_to_zip_file, add_data_to_viewer
 from .types import DataSetNames, VTKWriters, JoinedPolyData, ImageTypes
-from .config import DataConfig, Autocalculate
+from .config import DataConfig, Autocalculate, Config
 from .legend_parameter import Text
 
 
@@ -50,6 +53,40 @@ DATA_SETS = {
 }
 
 
+def _camera_to_grid_actor(actor: Actor, data_name: str, zoom: int = 2,
+                          auto_zoom: bool = True, camera_offset: int = 3,
+                          clipping_range: Tuple[int, int] = (0, 4), ) -> Camera:
+    """Create a Camera for a grid actor.
+
+    This function uses the center point of a grid actor to create a camera that is
+    setup at the camera_offset distance from the center point.
+
+    Args:
+        actor: An Actor object.
+        data_name: name of the data being loaded on the grid. This is 
+            used in naming the image files.
+        zoom: The zoom level of the camera. Defaults to 15.
+        auto_zoom: A boolean to set the camera to auto zoom. Setting this to True will
+            discard the Zoom level. Set this to False to use the zoom level. Defaults to 
+            True.
+        camera_offset: The distance between the camera and the sensor grid.
+            Defaults to 100.
+        clipping_range: The clipping range of the camera. Defaults to (100, 101).
+
+    Returns:
+        A Camera object.
+    """
+
+    cent_pt = actor.centroid
+    return Camera(identifier=f'{data_name}_{actor.name}',
+                  position=(cent_pt.x, cent_pt.y, cent_pt.z + camera_offset),
+                  projection='l',
+                  focal_point=cent_pt,
+                  clipping_range=clipping_range,
+                  parallel_scale=zoom,
+                  reset_camera=auto_zoom)
+
+
 class Model(object):
     """A honeybee-vtk model.
 
@@ -69,8 +106,8 @@ class Model(object):
     """
 
     def __init__(
-            self, model: HBModel,
-            load_grids: SensorGridOptions = SensorGridOptions.Ignore) -> None:
+            self, hb_model: HBModel,
+            grid_options: SensorGridOptions = SensorGridOptions.Ignore) -> None:
         """Instantiate a honeybee-vtk model object.
 
         Args:
@@ -80,26 +117,24 @@ class Model(object):
                 honeybee-vtk model.
         """
         super().__init__()
-        # apertures and orphaned apertures
-        self._apertures = \
-            ModelDataSet('Aperture', color=self.get_default_color('Aperture'))
-        # doors and orphaned doors
+
+        self._hb_model = hb_model
+        self._sensor_grids_option = grid_options
+        self._apertures = ModelDataSet('Aperture',
+                                       color=self.get_default_color('Aperture'))
         self._doors = ModelDataSet('Door', color=self.get_default_color('Door'))
-        # shades and orphaned shades
         self._shades = ModelDataSet('Shade', color=self.get_default_color('Shade'))
-        # face objects based on type
         self._walls = ModelDataSet('Wall', color=self.get_default_color('Wall'))
         self._floors = ModelDataSet('Floor', color=self.get_default_color('Floor'))
-        self._roof_ceilings = \
-            ModelDataSet('RoofCeiling', color=self.get_default_color('RoofCeiling'))
-        self._air_boundaries = \
-            ModelDataSet('AirBoundary', color=self.get_default_color('AirBoundary'))
+        self._roof_ceilings = ModelDataSet('RoofCeiling',
+                                           color=self.get_default_color('RoofCeiling'))
+        self._air_boundaries = ModelDataSet('AirBoundary',
+                                            color=self.get_default_color('AirBoundary'))
         self._sensor_grids = ModelDataSet('Grid', color=self.get_default_color('Grid'))
         self._cameras = []
-        self._convert_model(model)
-        self._load_grids(model, load_grids)
-        self._load_cameras(model)
-        self._sensor_grids_option = load_grids  # keep this for adding data
+        self._convert_model()
+        self._load_grids()
+        self._load_cameras()
 
     @classmethod
     def from_hbjson(cls, hbjson: str,
@@ -165,6 +200,11 @@ class Model(object):
         """List of Camera objects attached to this Model object."""
         return self._cameras
 
+    @cameras.setter
+    def cameras(self, cams: List(Camera)) -> None:
+        """Set the cameras for this Model object."""
+        self._cameras = cams
+
     def get_modeldataset(self, dataset: DataSetNames) -> ModelDataSet:
         """Get a ModelDataSet object from a model.
 
@@ -191,35 +231,36 @@ class Model(object):
         ):
             yield dataset
 
-    def _load_grids(self, model: HBModel, grid_options: SensorGridOptions) -> None:
+    def _load_grids(self) -> None:
         """Load sensor grids."""
-        if grid_options == SensorGridOptions.Ignore:
+        if self._sensor_grids_option == SensorGridOptions.Ignore:
             return
-        if hasattr(model.properties, 'radiance'):
+        if hasattr(self._hb_model.properties, 'radiance'):
             # list of unique sensor_grid identifiers in the model
-            ids = set([grid.identifier for grid in model.properties.radiance.sensor_grids])
+            ids = set([grid.identifier for grid in
+                       self._hb_model.properties.radiance.sensor_grids])
 
             # if all the grids have the same identifier, merge them into one grid
             if len(ids) == 1:
-                id = model.properties.radiance.sensor_grids[0].identifier
+                id = self._hb_model.properties.radiance.sensor_grids[0].identifier
                 sensors = [
-                    sensor for grid in model.properties.radiance.sensor_grids
+                    sensor for grid in self._hb_model.properties.radiance.sensor_grids
                     for sensor in grid.sensors]
                 sensor_grid = SensorGrid(id, sensors)
                 self._sensor_grids.data.append(
-                    convert_sensor_grid(sensor_grid, grid_options)
+                    convert_sensor_grid(sensor_grid, self._sensor_grids_option)
                 )
             # else add them as separate grids
             else:
-                for sensor_grid in model.properties.radiance.sensor_grids:
+                for sensor_grid in self._hb_model.properties.radiance.sensor_grids:
                     self._sensor_grids.data.append(
-                        convert_sensor_grid(sensor_grid, grid_options)
+                        convert_sensor_grid(sensor_grid, self._sensor_grids_option)
                     )
 
-    def _load_cameras(self, model: HBModel) -> None:
+    def _load_cameras(self) -> None:
         """Load radiance views."""
-        if len(model.properties.radiance.views) > 0:
-            for view in model.properties.radiance.views:
+        if len(self._hb_model.properties.radiance.views) > 0:
+            for view in self._hb_model.properties.radiance.views:
                 self._cameras.append(Camera.from_view(view))
 
     def update_display_mode(self, value: DisplayMode) -> None:
@@ -236,28 +277,28 @@ class Model(object):
         for attr in DATA_SETS.values():
             self.__getattribute__(attr).display_mode = value
 
-    def _convert_model(self, model: HBModel) -> None:
+    def _convert_model(self) -> None:
         """An internal method to convert the objects on class initiation."""
 
-        if hasattr(model, 'rooms'):
-            for room in model.rooms:
+        if hasattr(self._hb_model, 'rooms'):
+            for room in self._hb_model.rooms:
                 objects = convert_room(room)
                 self._add_objects(self.separate_by_type(objects))
 
-        if hasattr(model, 'orphaned_shades'):
-            for face in model.orphaned_shades:
+        if hasattr(self._hb_model, 'orphaned_shades'):
+            for face in self._hb_model.orphaned_shades:
                 self._shades.data.append(convert_shade(face))
 
-        if hasattr(model, 'orphaned_apertures'):
-            for face in model.orphaned_apertures:
+        if hasattr(self._hb_model, 'orphaned_apertures'):
+            for face in self._hb_model.orphaned_apertures:
                 self._apertures.data.extend(convert_aperture(face))
 
-        if hasattr(model, 'orphaned_doors'):
-            for face in model.orphaned_doors:
+        if hasattr(self._hb_model, 'orphaned_doors'):
+            for face in self._hb_model.orphaned_doors:
                 self._doors.data.extend(convert_door(face))
 
-        if hasattr(model, 'orphaned_faces'):
-            for face in model.orphaned_faces:
+        if hasattr(self._hb_model, 'orphaned_faces'):
+            for face in self._hb_model.orphaned_faces:
                 objects = convert_face(face)
                 self._add_objects(self.separate_by_type(objects))
 
@@ -378,7 +419,7 @@ class Model(object):
                 display_mode: DisplayMode = DisplayMode.Shaded) -> str:
         """Write the model to an HTML file.
 
-        Write your honeybee-vtk model to an HTML file that you can open in any modern 
+        Write your honeybee-vtk model to an HTML file that you can open in any modern
         browser and can also share with other.
 
         Args:
@@ -511,12 +552,13 @@ class Model(object):
 
         self.update_display_mode(model_display_mode)
         self.sensor_grids.display_mode = grid_display_mode
+
         if config:
             self.load_config(config, scene=scene, legend=True, validation=validation)
 
         # Set a default camera if there are no cameras in the model
         if not self.cameras and not view:
-            camera = Camera(identifier='plan', type='l')
+            camera = Camera(identifier='plan', projection='l')
             scene.add_cameras(camera)
             bounds = Actor.get_bounds(actors)
             centroid = Actor.get_centroid(actors)
@@ -524,21 +566,96 @@ class Model(object):
             scene.add_cameras(aerial_cameras)
 
         else:
-            # Collection cameras from model, if the model has it
             if len(self.cameras) != 0:
                 cameras = self.cameras
                 scene.add_cameras(cameras)
 
-            # if view files are provided collect them
             if view:
                 for vf in view:
                     camera = Camera.from_view_file(file_path=vf)
                     scene.add_cameras(camera)
 
+        for actor in scene.actors:
+            if actor.name == 'Grid':
+                print('Grid display mode', actor.modeldataset.display_mode)
+                assert actor.modeldataset.display_mode == grid_display_mode, 'Grid display'\
+                    ' mode is not set correctly.'
+            else:
+                assert actor.modeldataset.display_mode == model_display_mode, 'Model display'\
+                    ' mode is not set correctly.'
+
         return scene.export_images(
             folder=folder, image_type=image_type,
             image_width=image_width, image_height=image_height)
 
+    def to_grid_images(self,  *, folder: str = '.', config: str,
+                       grid_filter: List[str] = None,
+                       grid_display_mode: DisplayMode = DisplayMode.SurfaceWithEdges,
+                       background_color: Tuple[int, int, int] = None,
+                       image_type: ImageTypes = ImageTypes.png,
+                       image_width: int = 0, image_height: int = 0) -> List[str]:
+        """Export am image for each grid in the model.
+
+        Use the config file to specify which grids with which data to export. For
+        instance, if the config file has DataConfig objects for 'DA' and 'UDI', and
+        'DA' is kept hidden, then all grids with 'UDI' data will be exported. Additionally,
+        images from a selected number of grids can be exported by using the by
+        specifyling the identifiers of the grids to export in the grid_filter object in
+        the config file.
+
+        Args:
+            folder: Path to the folder where you'd like to export the images. Defaults to
+                    the current working directory.
+            config: Path to the config file in JSON format.
+            grid_filter: A list of grid identifiers to export images of those grid only.
+                Defaults to None which will export all the grids.
+            display_mode: Display mode for the grid. Defaults to surface with edges.
+            background_color: Background color of the image. Defaults to white.
+            image_type: Image type to be exported. Defaults to png.
+            image_width: Image width in pixels. Defaults to 0. Which will use the 
+                default radiance view's horizontal angle to derive the width.
+            image_height: Image height in pixels. Defaults to 0. Which will use the
+                default radiance view's vertical angle to derive the height.
+
+        Returns:
+            Path to the folder where the images are exported for each grid.
+        """
+        assert len(self.sensor_grids.data) != 0, 'No sensor grids found in the model.'
+
+        if self._sensor_grids_option == SensorGridOptions.Sensors:
+            grid_display_mode = DisplayMode.Points
+
+        config_data = self.load_config(config)
+
+        if not grid_filter:
+            grid_polydata_lst = self.sensor_grids.data
+        else:
+            grid_polydata_lst = [grid for grid in self.sensor_grids.data
+                                 if grid.name in grid_filter]
+            if not grid_polydata_lst:
+                raise ValueError('No grids found in the model that match the filter'
+                                 ' defined in the config file.')
+
+        image_paths: List[str] = []
+        for data in config_data:
+            for grid_polydata in grid_polydata_lst:
+                dataset = ModelDataSet(name=grid_polydata.identifier,
+                                       data=[grid_polydata],
+                                       display_mode=grid_display_mode)
+                dataset.color_by = data.identifier
+                actor = Actor(dataset)
+                scene = Scene(background_color=background_color)
+                scene.add_actors(actor)
+                scene.add_cameras(_camera_to_grid_actor(actor, data.identifier))
+                legend_range = self._get_legend_range(data)
+                self._load_legend_parameters(data, scene, legend_range)
+                image_paths += scene.export_images(folder=folder,
+                                                   image_type=image_type,
+                                                   image_width=image_width,
+                                                   image_height=image_height)
+
+        return image_paths
+
     @ staticmethod
     def get_default_color(face_type: face_types) -> Color:
         """Get the default color based of face type.
@@ -561,7 +678,7 @@ class Model(object):
         return data_dict
 
     def load_config(self, json_path: str, scene: Scene = None,
-                    validation: bool = False, legend: bool = False) -> Model:
+                    validation: bool = False, legend: bool = False) -> List[DataConfig]:
         """Mount data on model from config json.
 
         Args:
@@ -571,12 +688,13 @@ class Model(object):
             legend: A boolean indicating whether to load legend parameters.
 
         Returns:
-            A honeybee-vtk model with data loaded on it.
+            A list of parsed DataConfig objects.
         """
-        assert len(self.sensor_grids.data) > 0, 'Sensor grids are not loaded on'\
-            ' this model. Reload them using grid options.'
+        assert len(self.sensor_grids.data) > 0, 'Sensor grids are not loaded on'
+        ' this model. Reload them using grid options.'
 
         config_dir = pathlib.Path(json_path).parent
+        config_data: List[DataConfig] = []
 
         try:
             with open(json_path) as fh:
@@ -611,10 +729,12 @@ class Model(object):
                     # Load legend parameters
                     if legend:
                         self._load_legend_parameters(data, scene, legend_range)
+                    config_data.append(data)
                 else:
                     warnings.warn(
                         f'Data for {data.identifier} is not loaded.'
                     )
+            return config_data
 
     def _get_grid_type(self) -> str:
         """Get the type of grid in the model
@@ -736,14 +856,12 @@ class Model(object):
             ds.add_data_fields(
                 result, name=identifier, per_face=True, data_range=legend_range)
             ds.color_by = identifier
-            ds.display_mode = DisplayMode.SurfaceWithEdges
         else:
             ds.add_data_fields(
                 result, name=identifier, per_face=False, data_range=legend_range)
             ds.color_by = identifier
-            ds.display_mode = DisplayMode.Points
 
-    @staticmethod
+    @ staticmethod
     def _get_legend_range(data: DataConfig) -> List[Union[float, int]]:
         """Read and get legend min and max values from data if provided by the user.
 
@@ -781,6 +899,7 @@ class Model(object):
             legend_range: A list of min and max values of the legend parameters provided by
                 the user in the config file.
         """
+
         legend_params = data.legend_parameters
         legend = scene.legend_parameter(data.identifier)
 
@@ -793,6 +912,7 @@ class Model(object):
         legend.hide_legend = legend_params.hide_legend
         legend.orientation = legend_params.orientation
         legend.position = legend_params.position
+
         legend.width = legend_params.width
         legend.height = legend_params.height
 
